pub enum LeanWorkerRestartReason {
Explicit,
MaxRequests {
limit: u64,
},
MaxImports {
limit: u64,
},
RssCeiling {
current_kib: u64,
limit_kib: u64,
},
Idle {
idle_for: Duration,
limit: Duration,
},
Cancelled {
operation: &'static str,
},
RequestTimeout {
operation: &'static str,
duration: Duration,
},
}Expand description
Reason recorded for the latest worker cycle.
Variants
Explicit
The caller explicitly requested a process cycle.
MaxRequests
Request count reached the configured limit before the next request.
MaxImports
Import-like request count reached the configured limit before the next import.
RssCeiling
Child resident set size reached the configured limit.
Idle
Worker was idle at least as long as the configured limit.
Cancelled
Parent-side cancellation replaced the child during an in-flight request.
RequestTimeout
Parent-side request timeout replaced the child during an in-flight request.