LeanWorkerBootstrapReport

Struct LeanWorkerBootstrapReport 

pub struct LeanWorkerBootstrapReport { /* private fields */ }
Structured result of worker bootstrap checks for one capability builder.

Implementations

Source

impl LeanWorkerBootstrapReport

pub fn checks(&self) -> &[LeanWorkerBootstrapCheck]

All bootstrap findings.

pub fn errors(&self) -> impl Iterator<Item = &LeanWorkerBootstrapCheck>

Blocking bootstrap findings.

pub fn is_ok(&self) -> bool

Whether the worker bootstrap checks found no blocking findings.

pub fn first_error(&self) -> Option<&LeanWorkerBootstrapCheck>

First blocking finding, if any.