pub struct LeanWorkerCancellationToken { /* private fields */ }Expand description
Parent-side cancellation token for worker-session requests.
Cancellation is observed by the supervisor before a request is sent and at
worker progress frames while a request is in flight. In-flight cancellation
cycles the child process; it does not share an in-process
LeanCancellationToken with the child.
Implementations