pub struct LeanWorkerDeclarationRow {
pub name: String,
pub kind: String,
pub type_signature: Option<String>,
pub source: Option<LeanWorkerSourceRange>,
}Expand description
One declaration row returned by LeanWorkerSession::describe or
LeanWorkerSession::describe_bulk.
kind is the literal string LeanSession::declaration_kind returns
("axiom", "definition", "theorem", …, or "missing" for an absent
name). The describe_bulk path preserves the slot for absent names by
keeping kind == "missing" with type_signature: None and source: None
so the response length matches the input length.
Fields
name: Stringkind: Stringtype_signature: Option<String>source: Option<LeanWorkerSourceRange>Trait Implementations
Sourceimpl Clone for LeanWorkerDeclarationRow
impl Clone for LeanWorkerDeclarationRow
Sourcefn clone(&self) -> LeanWorkerDeclarationRow
fn clone(&self) -> LeanWorkerDeclarationRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeanWorkerDeclarationRow
impl Debug for LeanWorkerDeclarationRow
Sourceimpl<'de> Deserialize<'de> for LeanWorkerDeclarationRow
impl<'de> Deserialize<'de> for LeanWorkerDeclarationRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LeanWorkerDeclarationRow
impl PartialEq for LeanWorkerDeclarationRow
Sourcefn eq(&self, other: &LeanWorkerDeclarationRow) -> bool
fn eq(&self, other: &LeanWorkerDeclarationRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LeanWorkerDeclarationRow
impl Serialize for LeanWorkerDeclarationRow
impl Eq for LeanWorkerDeclarationRow
impl StructuralPartialEq for LeanWorkerDeclarationRow