pub struct LeanWorkerDiagnostic {
pub severity: String,
pub message: String,
pub file_label: String,
pub line: Option<u32>,
pub column: Option<u32>,
pub end_line: Option<u32>,
pub end_column: Option<u32>,
}Expand description
Serializable diagnostic returned by worker elaboration and kernel checks.
Fields
severity: Stringmessage: Stringfile_label: Stringline: Option<u32>column: Option<u32>end_line: Option<u32>end_column: Option<u32>Trait Implementations
Sourceimpl Clone for LeanWorkerDiagnostic
impl Clone for LeanWorkerDiagnostic
Sourcefn clone(&self) -> LeanWorkerDiagnostic
fn clone(&self) -> LeanWorkerDiagnostic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeanWorkerDiagnostic
impl Debug for LeanWorkerDiagnostic
Sourceimpl PartialEq for LeanWorkerDiagnostic
impl PartialEq for LeanWorkerDiagnostic
Sourcefn eq(&self, other: &LeanWorkerDiagnostic) -> bool
fn eq(&self, other: &LeanWorkerDiagnostic) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LeanWorkerDiagnostic
impl StructuralPartialEq for LeanWorkerDiagnostic