pub struct LeanWorkerDoctorReport {
pub diagnostics: Vec<LeanWorkerDoctorDiagnostic>,
pub metadata: Option<Value>,
}Expand description
Capability health report returned by a downstream doctor export.
Fields
diagnostics: Vec<LeanWorkerDoctorDiagnostic>metadata: Option<Value>Trait Implementations
Sourceimpl Clone for LeanWorkerDoctorReport
impl Clone for LeanWorkerDoctorReport
Sourcefn clone(&self) -> LeanWorkerDoctorReport
fn clone(&self) -> LeanWorkerDoctorReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeanWorkerDoctorReport
impl Debug for LeanWorkerDoctorReport
Sourceimpl PartialEq for LeanWorkerDoctorReport
impl PartialEq for LeanWorkerDoctorReport
Sourcefn eq(&self, other: &LeanWorkerDoctorReport) -> bool
fn eq(&self, other: &LeanWorkerDoctorReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LeanWorkerDoctorReport
impl StructuralPartialEq for LeanWorkerDoctorReport