pub struct LeanWorkerElabFailure {
pub diagnostics: Vec<LeanWorkerDiagnostic>,
pub truncated: bool,
}Expand description
Diagnostic payload returned alongside meta and elaboration failures.
truncated indicates the diagnostic projection hit the host byte budget
and later messages were dropped.
Fields
diagnostics: Vec<LeanWorkerDiagnostic>truncated: boolTrait Implementations
Sourceimpl Clone for LeanWorkerElabFailure
impl Clone for LeanWorkerElabFailure
Sourcefn clone(&self) -> LeanWorkerElabFailure
fn clone(&self) -> LeanWorkerElabFailure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeanWorkerElabFailure
impl Debug for LeanWorkerElabFailure
Sourceimpl<'de> Deserialize<'de> for LeanWorkerElabFailure
impl<'de> Deserialize<'de> for LeanWorkerElabFailure
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LeanWorkerElabFailure
impl PartialEq for LeanWorkerElabFailure
Sourcefn eq(&self, other: &LeanWorkerElabFailure) -> bool
fn eq(&self, other: &LeanWorkerElabFailure) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LeanWorkerElabFailure
impl Serialize for LeanWorkerElabFailure
impl Eq for LeanWorkerElabFailure
impl StructuralPartialEq for LeanWorkerElabFailure