LeanWorkerPoolSnapshot

Struct LeanWorkerPoolSnapshot 

pub struct LeanWorkerPoolSnapshot {
Show 28 fields pub max_workers: usize, pub workers: usize, pub active_workers: usize, pub warm_leases: usize, pub queue_depth: usize, pub total_child_rss_kib: Option<u64>, pub rss_samples_unavailable: u64, pub requests: u64, pub imports: u64, pub worker_restarts: u64, pub max_request_restarts: u64, pub max_import_restarts: u64, pub rss_restarts: u64, pub idle_restarts: u64, pub cancelled_restarts: u64, pub timeout_restarts: u64, pub policy_restarts: u64, pub queue_timeouts: u64, pub memory_budget_rejections: u64, pub last_restart_reason: Option<LeanWorkerRestartReason>, pub stream_requests: u64, pub stream_successes: u64, pub stream_failures: u64, pub data_rows_delivered: u64, pub data_row_payload_bytes: u64, pub stream_elapsed: Duration, pub backpressure_waits: u64, pub backpressure_failures: u64,
}
Summary of public pool state.

This snapshot exposes admission and reuse facts without revealing worker ids, child pids, pipe handles, or which warm child will be selected.

Fields

max_workers: usizeworkers: usizeactive_workers: usizewarm_leases: usizequeue_depth: usizetotal_child_rss_kib: Option<u64>rss_samples_unavailable: u64requests: u64imports: u64worker_restarts: u64max_request_restarts: u64max_import_restarts: u64rss_restarts: u64idle_restarts: u64cancelled_restarts: u64timeout_restarts: u64policy_restarts: u64queue_timeouts: u64memory_budget_rejections: u64last_restart_reason: Option<LeanWorkerRestartReason>stream_requests: u64stream_successes: u64stream_failures: u64data_rows_delivered: u64data_row_payload_bytes: u64stream_elapsed: Durationbackpressure_waits: u64backpressure_failures: u64