pub struct LeanWorkerProgressEvent {
pub phase: String,
pub current: u64,
pub total: Option<u64>,
pub elapsed: Duration,
}Expand description
One progress event observed by the parent from a worker request.
Fields
phase: Stringcurrent: u64total: Option<u64>elapsed: DurationTrait Implementations
Sourceimpl Clone for LeanWorkerProgressEvent
impl Clone for LeanWorkerProgressEvent
Sourcefn clone(&self) -> LeanWorkerProgressEvent
fn clone(&self) -> LeanWorkerProgressEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeanWorkerProgressEvent
impl Debug for LeanWorkerProgressEvent
Sourceimpl PartialEq for LeanWorkerProgressEvent
impl PartialEq for LeanWorkerProgressEvent
Sourcefn eq(&self, other: &LeanWorkerProgressEvent) -> bool
fn eq(&self, other: &LeanWorkerProgressEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LeanWorkerProgressEvent
impl StructuralPartialEq for LeanWorkerProgressEvent