LeanWorkerRuntimeMetadata

Struct LeanWorkerRuntimeMetadata 

pub struct LeanWorkerRuntimeMetadata {
    pub worker_version: String,
    pub protocol_version: u16,
    pub lean_version: Option<String>,
}
Protocol/runtime facts reported by the worker child during handshake.

These facts describe the lean-rs-worker process and framing contract. They are separate from downstream capability metadata returned by LeanWorkerSession::capability_metadata.

Fields

worker_version: Stringprotocol_version: u16lean_version: Option<String>