#[non_exhaustive]pub enum LeanWorkerBootstrapDiagnosticCode {
WorkerChildUnresolved,
WorkerChildNotExecutable,
CapabilityPreflight {
code: LeanLoaderDiagnosticCode,
},
WorkerHandshakeFailed,
CapabilityMetadataMismatch,
WorkerStartupFailed,
}Expand description
Stable worker bootstrap diagnostic codes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WorkerChildUnresolved
The worker child locator did not resolve to a file.
WorkerChildNotExecutable
The worker child exists but is not executable.
CapabilityPreflight
Manifest-backed capability preflight reported a loader/artifact issue.
Fields
WorkerHandshakeFailed
The worker child did not complete the protocol handshake.
CapabilityMetadataMismatch
Capability metadata did not match the caller’s expectation.
WorkerStartupFailed
Worker bootstrap failed for a reason outside the named deployment checks.
Implementations