pub struct LeanWorkerImportPlanner { /* private fields */ }Expand description
Planner for worker-pool import/session batches.
Implementations
Sourceimpl LeanWorkerImportPlanner
impl LeanWorkerImportPlanner
Sourcepub fn new(config: LeanWorkerImportPlanConfig) -> Self
pub fn new(config: LeanWorkerImportPlanConfig) -> Self
Create a planner from capability/session requirements.
Sourcepub fn plan_lake_project(
&self,
) -> Result<Vec<LeanWorkerPlannedBatch>, LeanWorkerImportPlanError>
pub fn plan_lake_project( &self, ) -> Result<Vec<LeanWorkerPlannedBatch>, LeanWorkerImportPlanError>
Discover a Lake project and return stable worker batches.
Errors
Returns typed planning diagnostics for missing Lake roots, selected module roots, invalid module names, unsupported toolchains, or an unresolved capability target.
Sourcepub fn plan_discovered(
&self,
discovered: &LeanLakeProjectModules,
) -> Result<Vec<LeanWorkerPlannedBatch>, LeanWorkerImportPlanError>
pub fn plan_discovered( &self, discovered: &LeanLakeProjectModules, ) -> Result<Vec<LeanWorkerPlannedBatch>, LeanWorkerImportPlanError>
Plan batches from already discovered module descriptors.
Errors
Returns a typed error if a supplied module descriptor has an invalid module name.
Sourcepub fn plan_work_items(
&self,
modules: impl IntoIterator<Item = LeanWorkerModuleWork>,
source_set: &LeanModuleSetFingerprint,
) -> Result<Vec<LeanWorkerPlannedBatch>, LeanWorkerImportPlanError>
pub fn plan_work_items( &self, modules: impl IntoIterator<Item = LeanWorkerModuleWork>, source_set: &LeanModuleSetFingerprint, ) -> Result<Vec<LeanWorkerPlannedBatch>, LeanWorkerImportPlanError>
Plan batches from caller-provided module work items.
Errors
Returns a typed error if a supplied work item has an invalid module name.