pub struct LeanWorkerRuntimeMetadata {
pub worker_version: String,
pub protocol_version: u16,
pub lean_version: Option<String>,
}Expand description
Protocol/runtime facts reported by the worker child during handshake.
These facts describe the lean-rs-worker process and framing contract.
They are separate from downstream capability metadata returned by
LeanWorkerSession::capability_metadata.
Fields
worker_version: Stringprotocol_version: u16lean_version: Option<String>Trait Implementations
Sourceimpl Clone for LeanWorkerRuntimeMetadata
impl Clone for LeanWorkerRuntimeMetadata
Sourcefn clone(&self) -> LeanWorkerRuntimeMetadata
fn clone(&self) -> LeanWorkerRuntimeMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeanWorkerRuntimeMetadata
impl Debug for LeanWorkerRuntimeMetadata
Sourceimpl PartialEq for LeanWorkerRuntimeMetadata
impl PartialEq for LeanWorkerRuntimeMetadata
Sourcefn eq(&self, other: &LeanWorkerRuntimeMetadata) -> bool
fn eq(&self, other: &LeanWorkerRuntimeMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LeanWorkerRuntimeMetadata
impl StructuralPartialEq for LeanWorkerRuntimeMetadata